%bcond_with ssl

%define major     30
%define sslmajor  27
%define xxmajor   30
%define danemajor 0
%define libname   %mklibname %{name} %{major}
%define libssl    %mklibname %{name}-ssl %{sslmajor}
%define libxx     %mklibname %{name}xx %{xxmajor}
%define develname %mklibname %{name} -d
%define libdane   %mklibname %{name}-dane %{danemajor}

%define url_ver %(echo %{version}|cut -d. -f1,2)

Summary:        Library providing a secure layer (SSL)
Name:           gnutls
Version:        3.8.0
%define subrel 1
Release:        %mkrel 2
License:        LGPLv2+
Group:          Security
URL:            https://www.gnutls.org/
Source0:        https://www.gnupg.org/ftp/gcrypt/gnutls/v%{url_ver}/%{name}-%{version}.tar.xz
Source1:        https://www.gnupg.org/ftp/gcrypt/gnutls/v%{url_ver}/%{name}-%{version}.tar.xz.sig
# Fix desychronisation with kTLS:
# https://gitlab.com/gnutls/gnutls/-/issues/1470
Patch1:         gnutls-3.8.0-ktls-Do-not-return-GNUTLS_E_INTERRUPTED-AGAIN-from-s.patch
Patch2:         CVE-2023-5981.patch

BuildRequires:  liblzo-devel
BuildRequires:  pkgconfig(nettle) >= 3.4.1
BuildRequires:  pkgconfig(libtasn1) >= 4.3
BuildRequires:  pkgconfig(p11-kit-1) >= 0.23.1
BuildRequires:  pkgconfig(libidn2)
BuildRequires:  pkgconfig(readline)
%ifnarch %arm %mips aarch64
BuildRequires:  valgrind
%endif
BuildRequires:  pkgconfig(opencdk)
BuildRequires:  gettext-devel
BuildRequires:  autogen
BuildRequires:  pkgconfig(autoopts)
BuildRequires:  texinfo
BuildRequires:  pkgconfig(libunbound)
BuildRequires:  pkgconfig(tss2-esys)
Requires:       crypto-policies

%description
GnuTLS is a project that aims to develop a library which provides
a secure layer, over a reliable transport layer.

%package -n %{libname}
Summary:        Library providing a secure layer (SSL)
Group:          System/Libraries
Provides:       lib%{name} = %{version}-%{release}

%description -n %{libname}
GnuTLS is a project that aims to develop a library which provides
a secure layer, over a reliable transport layer.

%if %{with ssl}
%package -n %{libssl}
Summary:        Library providing a secure layer (SSL)
Group:          System/Libraries

%description -n %{libssl}
GnuTLS is a project that aims to develop a library which provides
a secure layer, over a reliable transport layer.
%endif

%package -n %{libxx}
Summary:        Library providing a secure layer (SSL)
Group:          System/Libraries
# This conflict can be dropped when the xx lib also changes major
%define libname28 %mklibname %{name} 28
Conflicts:      %{libname28}

%description -n %{libxx}
GnuTLS is a project that aims to develop a library which provides
a secure layer, over a reliable transport layer.

%package -n %{libdane}
Summary:        Library supporting the dane certificate checker
Group:          System/Libraries
Provides:       lib%{name}-dane = %{version}-%{release}
Conflicts:      %{_lib}gnutls30 < 3.7.3-2

%description -n %{libdane}
GnuTLS is a project that aims to develop a library which provides
a secure layer, over a reliable transport layer.

%package -n %{develname}
Summary:        Development files for %{name}
Group:          Development/C
Requires:       %{name} = %{version}-%{release}
Requires:       %{libname} = %{version}-%{release}
%if %{with ssl}
Requires:       %{libssl} = %{version}-%{release}
%endif
Requires:       %{libxx} = %{version}-%{release}
Requires:       %{libdane} = %{version}-%{release}
Provides:       lib%{name}-devel = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}

%description -n %{develname}
GnuTLS is a project that aims to develop a library which provides
a secure layer, over a reliable transport layer.

This package contains all necessary files to compile or develop
programs/libraries that use %{name}.

%prep
%autosetup -p1

echo "SYSTEM=NORMAL" >> tests/system.prio

%build
%configure \
    --disable-static \
    --with-included-libtasn1=no \
    --enable-sha1-support \
%ifarch %{ix86}
    --disable-year2038 \
%endif
%if %{with ssl}
    --disable-openssl-compatibility \
%endif
    --with-system-priority-file=%{_sysconfdir}/crypto-policies/back-ends/gnutls.config \
    --disable-gtk-doc-html \
%ifnarch %arm %mips
    --enable-valgrind-tests \
%endif
    --with-tpm2 \
    --enable-ktls \
    --disable-rpath \
    --with-default-priority-string="@SYSTEM"

%make_build

%check
#__make check

%install
%make_install

%find_lang %{name}

find %{buildroot} -name '*.la' -delete

# (akien) We don't need to install those images if we don't ship the rest of the docs
rm -rf %{buildroot}%{_docdir}/%{name}

%files -f %{name}.lang
%doc NEWS README.md
%{_bindir}/[cgs]*
%{_bindir}/psktool
%{_bindir}/p11tool
%{_bindir}/ocsptool
%{_bindir}/danetool
%{_mandir}/man?/*
%{_infodir}/*

%files -n %{libname}
%{_libdir}/libgnutls.so.%{major}
%{_libdir}/libgnutls.so.%{major}.*

%files -n %{libdane}
%{_libdir}/libgnutls-dane.so.%{danemajor}
%{_libdir}/libgnutls-dane.so.%{danemajor}.*

%files -n %{libxx}
%{_libdir}/libgnutlsxx.so.%{xxmajor}
%{_libdir}/libgnutlsxx.so.%{xxmajor}.*

%if %{with ssl}
%files -n %{libssl}
%{_libdir}/libgnutls-openssl.so.%{sslmajor}
%{_libdir}/libgnutls-openssl.so.%{sslmajor}.*
%endif

%files -n %{develname}
%{_libdir}/libgnutls*.so
%{_libdir}/pkgconfig/%{name}.pc
%{_libdir}/pkgconfig/%{name}-dane.pc
%{_includedir}/gnutls/


%changelog
* Mon Jan 08 2024 ns80 <ns80> 3.8.0-2.1.mga9
+ Revision: 2028953
- backport upstream patch for CVE-2023-5981 (mga#32547)

* Sat Mar 11 2023 daviddavid <daviddavid> 3.8.0-2.mga9
+ Revision: 1948585
- disable GNULIB's year2038 support for 64-bit time_t
    GNUTLS exposes time_t in its public API and thus the size of time_t
    is ABI relevant. It can't be changed in size without breaking
    ABI compatibility with applications built against GNUTLS that use
    the default time_t size.
    https://gitlab.com/gnutls/gnutls/-/issues/1466
- enable ktls support
- fix desychronisation with kTLS:
  * https://gitlab.com/gnutls/gnutls/-/issues/1470
- enable tpm2 support
- enable allow SHA1 sign support

* Sun Feb 19 2023 daviddavid <daviddavid> 3.8.0-1.mga9
+ Revision: 1944136
- new version: 3.8.0, fixes CVE-2023-0361 (mga#31558)

* Thu Jan 12 2023 daviddavid <daviddavid> 3.7.8-2.mga9
+ Revision: 1932551
- rebuild for new libunistring 1.1

* Tue Nov 22 2022 guillomovitch <guillomovitch> 3.7.8-1.mga9
+ Revision: 1910004
- new version 3.7.8

* Mon Aug 01 2022 luigiwalser <luigiwalser> 3.7.7-1.mga9
+ Revision: 1874205
- 3.7.7

* Thu Jun 02 2022 luigiwalser <luigiwalser> 3.7.6-1.mga9
+ Revision: 1861049
- 3.7.6

* Sat May 07 2022 luigiwalser <luigiwalser> 3.7.4-1.mga9
+ Revision: 1856677
- gnutlsxx major is now 30
- 3.7.4
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Thu Jan 27 2022 mrambo3501 <mrambo3501> 3.7.3-2.mga9
+ Revision: 1770010
- fix incorrect dane library configuration

* Wed Jan 26 2022 mrambo3501 <mrambo3501> 3.7.3-1.mga9
+ Revision: 1769921
- version 3.7.3
- BR pkgconfig(libunbound) to build DANE

* Sun Jun 06 2021 luigiwalser <luigiwalser> 3.7.2-1.mga9
+ Revision: 1729935
- 3.7.2

* Fri Apr 09 2021 daviddavid <daviddavid> 3.7.1-1.mga9
+ Revision: 1714343
- new version: 3.7.1

* Wed Dec 16 2020 tv <tv> 3.6.15-3.mga8
+ Revision: 1658190
- rebuild for new p11-kit

* Sun Nov 29 2020 luigiwalser <luigiwalser> 3.6.15-2.mga8
+ Revision: 1650423
- rebuild for nettle

* Mon Sep 07 2020 luigiwalser <luigiwalser> 3.6.15-1.mga8
+ Revision: 1623399
- 3.6.15

* Wed Aug 19 2020 ovitters <ovitters> 3.6.14-2.mga8
+ Revision: 1615979
- remove install-info scriptlets, rely on filetrigger instead (mga#27107)

* Thu Jun 04 2020 daviddavid <daviddavid> 3.6.14-1.mga8
+ Revision: 1590267
- new version: 3.6.14
- remove merged upstream patches

* Sun May 31 2020 daviddavid <daviddavid> 3.6.13-2.mga8
+ Revision: 1589309
- Fix cert chain validation behavior if the last cert has expired (#1842178)
- Add option to gnutls-cli to wait for resumption under TLS 1.3
- Disable RSA blinding during FIPS self-tests

* Mon Apr 06 2020 luigiwalser <luigiwalser> 3.6.13-1.mga8
+ Revision: 1565344
- 3.6.13

* Mon Mar 02 2020 daviddavid <daviddavid> 3.6.12-1.mga8
+ Revision: 1552778
- new version: 3.6.12

* Tue Feb 18 2020 umeabot <umeabot> 3.6.11-2.mga8
+ Revision: 1541918
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Fri Jan 03 2020 luigiwalser <luigiwalser> 3.6.11-1.mga8
+ Revision: 1475622
- 3.6.11

* Tue Oct 01 2019 daviddavid <daviddavid> 3.6.10-1.mga8
+ Revision: 1448628
- new version: 3.6.10
- new version: 3.6.9

* Sat Jul 13 2019 daviddavid <daviddavid> 3.6.8-1.mga8
+ Revision: 1420888
- new version: 3.6.8

* Thu Mar 28 2019 luigiwalser <luigiwalser> 3.6.7-1.mga7
+ Revision: 1380765
- 3.6.7 (fixes CVE-2019-3829 and CVE-2019-3836)

* Wed Feb 13 2019 luigiwalser <luigiwalser> 3.6.6-2.mga7
+ Revision: 1366527
- rebuild for libidn2

* Sat Feb 02 2019 luigiwalser <luigiwalser> 3.6.6-1.mga7
+ Revision: 1362668
- 3.6.6

* Wed Jan 09 2019 wally <wally> 3.6.5-2.mga7
+ Revision: 1353598
- rebuild for new libidn2

* Sun Dec 16 2018 wally <wally> 3.6.5-1.mga7
+ Revision: 1341811
- new version 3.6.5

* Mon Oct 15 2018 luigiwalser <luigiwalser> 3.6.4-1.mga7
+ Revision: 1320659
- 3.6.4
- remove upstreamed patch 1

* Sun Sep 23 2018 umeabot <umeabot> 3.6.3-3.mga7
+ Revision: 1298002
- Mageia 7 Mass Rebuild

* Sat Jul 21 2018 tmb <tmb> 3.6.3-2.mga7
+ Revision: 1244651
- gnutls_priority_init: fix err_pos on invalid strings
- enable TLS 1.3
- update to 3.6.3

* Wed Mar 28 2018 kekepower <kekepower> 3.6.2-1.mga7
+ Revision: 1213072
- Update to version 3.6.2

* Fri Oct 27 2017 guillomovitch <guillomovitch> 3.6.1-3.mga7
+ Revision: 1174075
- enable tests

* Fri Oct 27 2017 tv <tv> 3.6.1-2.mga7
+ Revision: 1174046
- fix lftp regression due to bogus usage of system-wide crypto policies (mga#21949)
- new release

* Wed Oct 11 2017 wally <wally> 3.6.0-2.mga7
+ Revision: 1171051
- build with libidn2

* Thu Aug 24 2017 guillomovitch <guillomovitch> 3.6.0-1.mga7
+ Revision: 1147609
- new version 3.6.0
- add support for system-wide cipher selection policies

* Sat Jun 10 2017 luigiwalser <luigiwalser> 3.5.13-1.mga6
+ Revision: 1107434
- 3.5.13 (fixes CVE-2017-7507)

* Tue May 23 2017 luigiwalser <luigiwalser> 3.5.12-1.mga6
+ Revision: 1104139
- 3.5.12

* Tue Apr 11 2017 luigiwalser <luigiwalser> 3.5.11-1.mga6
+ Revision: 1096368
- 3.5.11

* Wed Mar 08 2017 luigiwalser <luigiwalser> 3.5.10-1.mga6
+ Revision: 1089826
- 3.5.10

* Sun Feb 19 2017 luigiwalser <luigiwalser> 3.5.9-1.mga6
+ Revision: 1086830
- 3.5.9

* Tue Jan 10 2017 luigiwalser <luigiwalser> 3.5.8-1.mga6
+ Revision: 1080844
- 3.5.8

* Mon Dec 12 2016 luigiwalser <luigiwalser> 3.4.17-1.mga6
+ Revision: 1074400
- 3.4.17

* Wed Oct 26 2016 luigiwalser <luigiwalser> 3.4.16-1.mga6
+ Revision: 1063587
- 3.4.16

* Wed Sep 14 2016 luigiwalser <luigiwalser> 3.4.15-1.mga6
+ Revision: 1052925
- 3.4.15

* Tue Jul 12 2016 luigiwalser <luigiwalser> 3.4.14-1.mga6
+ Revision: 1041303
- 3.4.14 (fixes GNUTLS-SA-2016-2)

* Tue Jun 07 2016 luigiwalser <luigiwalser> 3.4.13-1.mga6
+ Revision: 1020529
- 3.4.13

* Mon May 09 2016 luigiwalser <luigiwalser> 3.4.11-1.mga6
+ Revision: 1011379
- 3.4.11

* Sun Mar 20 2016 wally <wally> 3.4.9-2.mga6
+ Revision: 993130
- drop unneeded requires

* Mon Feb 15 2016 luigiwalser <luigiwalser> 3.4.9-1.mga6
+ Revision: 961382
- 3.4.9

* Tue Jan 12 2016 pterjan <pterjan> 3.4.8-6.mga6
+ Revision: 922097
- Fix conflict to apply to the old lib

* Tue Jan 12 2016 tv <tv> 3.4.8-5.mga6
+ Revision: 922069
- move conflict where it belongs :-(

* Tue Jan 12 2016 tv <tv> 3.4.8-4.mga6
+ Revision: 922065
- xx subpkg must conflict with main packager after split

* Tue Jan 12 2016 luigiwalser <luigiwalser> 3.4.8-3.mga6
+ Revision: 922022
- re-enable libgnutlsxx dep in libgnutls-devel

* Mon Jan 11 2016 luigiwalser <luigiwalser> 3.4.8-2.mga6
+ Revision: 921866
- temporarily disable requires of libgnutlsxx in libgnutls-devel

* Mon Jan 11 2016 luigiwalser <luigiwalser> 3.4.8-1.mga6
+ Revision: 921784
- 3.4.8
- library major is now 30
- split gnutlsxx lib into own subpackage (still major 28)
- disable openssl compatibility library by default

* Mon Jan 11 2016 luigiwalser <luigiwalser> 3.3.20-1.mga6
+ Revision: 921767
- 3.3.20

* Fri Aug 21 2015 tmb <tmb> 3.3.17-2.mga6
+ Revision: 867589
- rebuild for new gcc

* Mon Aug 17 2015 fwang <fwang> 3.3.17-1.mga6
+ Revision: 865206
- update file list
- br libopts-devel
- reconf at first
- now we support nettle 3.0
- 3.3.17
+ luigiwalser <luigiwalser>
- add upstream patch to fix GNUTLS-SA-2015-3

* Tue May 05 2015 luigiwalser <luigiwalser> 3.2.21-3.mga6
+ Revision: 821272
- rediff upstream patch to fix GNUTLS-SA-2015-2
- replace CVE-2015-0294 fix from upstream 3.3.x branch with one from 3.2.x
- rediff upstream patch to fix CVE-2015-0294

* Fri Dec 19 2014 luigiwalser <luigiwalser> 3.2.21-1.mga5
+ Revision: 804318
- 3.2.21

* Thu Nov 13 2014 luigiwalser <luigiwalser> 3.2.20-1.mga5
+ Revision: 796753
- 3.2.20 (fixes CVE-2014-8564)

* Wed Oct 15 2014 umeabot <umeabot> 3.2.17-3.mga5
+ Revision: 741358
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 3.2.17-2.mga5
+ Revision: 679838
- Mageia 5 Mass Rebuild

* Sun Aug 31 2014 luigiwalser <luigiwalser> 3.2.17-1.mga5
+ Revision: 670117
- 3.2.17

* Wed Aug 13 2014 luigiwalser <luigiwalser> 3.2.16-2.mga5
+ Revision: 662357
- gnutls-devel requires nettle 2.7 devel, not nettle 3.0 devel

* Mon Aug 04 2014 luigiwalser <luigiwalser> 3.2.16-1.mga5
+ Revision: 659585
- 3.2.16
- BR nettle2.7-devel
+ dmorgan <dmorgan>
- Rebuild against new libnettle

* Fri May 30 2014 luigiwalser <luigiwalser> 3.2.15-1.mga5
+ Revision: 628016
- 3.2.15 (fixes CVE-2014-3466)

* Sat Apr 26 2014 luigiwalser <luigiwalser> 3.2.13-1.mga5
+ Revision: 618247
- 3.2.13

* Thu Mar 06 2014 luigiwalser <luigiwalser> 3.2.12.1-1.mga5
+ Revision: 600303
- 3.2.12.1

* Mon Mar 03 2014 luigiwalser <luigiwalser> 3.2.12-1.mga5
+ Revision: 598856
- 3.2.12 (fixes CVE-2014-0092)

* Fri Feb 14 2014 oden <oden> 3.2.11-1.mga5
+ Revision: 591051
- 3.2.11 (fixes CVE-2014-1959)

* Tue Feb 04 2014 fwang <fwang> 3.2.10-1.mga5
+ Revision: 581616
- new version 3.2.10

* Thu Dec 05 2013 luigiwalser <luigiwalser> 3.2.7-1.mga4
+ Revision: 555427
- 3.2.7

* Tue Nov 05 2013 luigiwalser <luigiwalser> 3.2.6-1.mga4
+ Revision: 549728
- 3.2.6 (fixes regression in CVE-2013-4466 fix)
- 3.2.5 (fixes CVE-2013-4466)

* Sat Oct 19 2013 umeabot <umeabot> 3.2.4-2.mga4
+ Revision: 533585
- Mageia 4 Mass Rebuild

* Sun Sep 01 2013 fwang <fwang> 3.2.4-1.mga4
+ Revision: 474006
- new version 3.2.4

* Thu Aug 08 2013 luigiwalser <luigiwalser> 3.2.3-1.mga4
+ Revision: 464788
- 3.2.3

* Mon Jul 15 2013 fwang <fwang> 3.2.2-1.mga4
+ Revision: 454579
- br makeinfo
- new version 3.2.2

* Sun Jun 02 2013 fwang <fwang> 3.2.1-1.mga4
+ Revision: 434882
- disable check as it always broken
- fix linkage
- new version 3.2.1
- update license
- new version 3.2.0

* Fri May 24 2013 luigiwalser <luigiwalser> 3.1.10-1.mga4
+ Revision: 426655
- 3.1.10

* Tue Feb 12 2013 fwang <fwang> 3.1.8-2.mga3
+ Revision: 397999
- add versioned requires

* Mon Feb 11 2013 guillomovitch <guillomovitch> 3.1.8-1.mga3
+ Revision: 397858
- new version

* Sat Jan 12 2013 umeabot <umeabot> 3.1.6-2.mga3
+ Revision: 352394
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Jan 08 2013 luigiwalser <luigiwalser> 3.1.6-1.mga3
+ Revision: 343153
- disable trousers support (tpmtool), possible license problem + will not build
- 3.1.6
+ fwang <fwang>
- update url

* Sun Nov 25 2012 fwang <fwang> 3.1.5-1.mga3
+ Revision: 321715
- update file list
- new version 3.1.5

* Tue Oct 30 2012 fwang <fwang> 3.1.3-2.mga3
+ Revision: 311613
- rebuild for new libtasn1
- update rpm group

* Sun Oct 14 2012 fwang <fwang> 3.1.3-1.mga3
+ Revision: 305299
- new version 3.1.3

* Sat Sep 29 2012 fwang <fwang> 3.1.2-1.mga3
+ Revision: 299993
- new version 3.1.2
- update file list

* Mon Sep 03 2012 fwang <fwang> 3.1.1-1.mga3
+ Revision: 287473
- new version 3.1.1
- br trousers

* Thu Aug 30 2012 fwang <fwang> 3.1.0-1.mga3
+ Revision: 285840
- new version 3.1.0

* Sun Aug 05 2012 fwang <fwang> 3.0.22-1.mga3
+ Revision: 278673
- new version 3.0.22

* Thu Jul 05 2012 fwang <fwang> 3.0.21-1.mga3
+ Revision: 267829
- new version 3.0.21

* Wed Jun 06 2012 fwang <fwang> 3.0.20-1.mga3
+ Revision: 256040
- new version 3.0.20

* Thu May 31 2012 fwang <fwang> 3.0.19-1.mga3
+ Revision: 251962
- new version 3.0.19

* Tue Apr 03 2012 guillomovitch <guillomovitch> 3.0.18-1.mga2
+ Revision: 228256
- new version

* Wed Mar 21 2012 fwang <fwang> 3.0.17-1.mga2
+ Revision: 225152
- new version 3.0.17

* Sun Mar 04 2012 fwang <fwang> 3.0.15-2.mga2
+ Revision: 217803
- dont know why it is providing a wrong name

* Sun Mar 04 2012 fwang <fwang> 3.0.15-1.mga2
+ Revision: 217753
- update file list
- new version 3.0.15
- new version 3.0.14
- specify mageia info
- new version 3.0.12

* Thu Jan 12 2012 fwang <fwang> 3.0.11-1.mga2
+ Revision: 195122
- new version 3.0.11

* Wed Dec 14 2011 fwang <fwang> 3.0.9-1.mga2
+ Revision: 181525
- new version 3.0.9

* Tue Nov 22 2011 fwang <fwang> 3.0.8-1.mga2
+ Revision: 170780
- new version 3.0.8
- new version 3.0.5

* Sat Oct 15 2011 fwang <fwang> 3.0.4-1.mga2
+ Revision: 155340
- bump nettle req
- new version 3.0.4

* Mon Sep 19 2011 fwang <fwang> 3.0.3-1.mga2
+ Revision: 145486
- new verrsion 3.0.3

* Thu Sep 01 2011 fwang <fwang> 3.0.2-1.mga2
+ Revision: 137640
- new version 3.0.2
- new version 3.0.1
- update file list
- br p11-kit
- new version 3.0.0 (only nettle backend is supported)

* Fri Jun 24 2011 mikala <mikala> 2.12.7-2.mga2
+ Revision: 113217
- Build with --with-libgcrypt instead of nettle
- Add patch0 from fedora to skip dsa tests
- Add back %%ifnarch for arm & mips (we do have an arm port where valgrind is not available)

* Tue Jun 21 2011 fwang <fwang> 2.12.7-1.mga2
+ Revision: 111574
- new verison 2.12.7 (nettle based)

* Thu Mar 24 2011 boklm <boklm> 2.10.5-2.mga1
+ Revision: 76149
- rebuild for bug #497

* Fri Mar 18 2011 wally <wally> 2.10.5-1.mga1
+ Revision: 74054
- new version 2.10.5
- drop buildroot definition

* Wed Jan 12 2011 ahmad <ahmad> 2.10.4-2.mga1
+ Revision: 6790
- drop old/unneeded scriptlets
- imported package gnutls


* Tue Dec 07 2010 Sandro Cazzaniga <kharec@mandriva.org> 2.10.4-1mdv2011.0
+ Revision: 614395
- new version 2.10.4

* Sun Nov 21 2010 Funda Wang <fwang@mandriva.org> 2.10.3-1mdv2011.0
+ Revision: 599501
- new version 2.10.3

* Sat Oct 16 2010 Funda Wang <fwang@mandriva.org> 2.10.2-1mdv2011.0
+ Revision: 585921
- new version 2.10.2

* Sun Jul 25 2010 Sandro Cazzaniga <kharec@mandriva.org> 2.10.1-1mdv2011.0
+ Revision: 559776
- update to 2.10.1

* Sat Jul 10 2010 Funda Wang <fwang@mandriva.org> 2.10.0-1mdv2011.0
+ Revision: 549968
- New version 2.10.0

* Sat Mar 20 2010 Emmanuel Andry <eandry@mandriva.org> 2.8.6-1mdv2010.1
+ Revision: 525446
- New version 2.8.6

* Fri Nov 06 2009 Funda Wang <fwang@mandriva.org> 2.8.5-1mdv2010.1
+ Revision: 461828
- add sig
- new version 2.8.5

* Tue Oct 06 2009 Thierry Vignaud <tv@mandriva.org> 2.8.4-3mdv2010.0
+ Revision: 454737
- do not package huge ChangeLog

* Fri Sep 25 2009 Olivier Blin <oblin@mandriva.com> 2.8.4-2mdv2010.0
+ Revision: 448974
- disable valgrind for mips & arm (from Arnaud Patard)

* Sun Sep 20 2009 Tomasz Pawel Gajc <tpg@mandriva.org> 2.8.4-1mdv2010.0
+ Revision: 444963
- update to new version 2.8.4

* Thu Aug 13 2009 Emmanuel Andry <eandry@mandriva.org> 2.8.3-1mdv2010.0
+ Revision: 416093
- New version 2.8.3

* Wed Aug 12 2009 Emmanuel Andry <eandry@mandriva.org> 2.8.2-1mdv2010.0
+ Revision: 415669
- New version 2.8.2
- drop P1 (merged upstream)

* Tue Jul 07 2009 Eugeni Dodonov <eugeni@mandriva.com> 2.8.1-2mdv2010.0
+ Revision: 393087
- Added upstream patch to fix EAGAIN happening too often.

* Thu Jun 11 2009 Frederik Himpe <fhimpe@mandriva.org> 2.8.1-1mdv2010.0
+ Revision: 385184
- Update to new version 2.8.1

* Fri May 29 2009 Funda Wang <fwang@mandriva.org> 2.8.0-1mdv2010.0
+ Revision: 381086
- New version 2.8.0

* Fri May 01 2009 Funda Wang <fwang@mandriva.org> 2.6.6-1mdv2010.0
+ Revision: 369945
- New version 2.6.6

* Tue Feb 10 2009 Tomasz Pawel Gajc <tpg@mandriva.org> 2.6.4-1mdv2009.1
+ Revision: 339088
- update to new version 2.6.4

* Tue Dec 16 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 2.6.3-1mdv2009.1
+ Revision: 315015
- update to new version 2.6.3

* Tue Dec 16 2008 Oden Eriksson <oeriksson@mandriva.com> 2.6.2-2mdv2009.1
+ Revision: 314900
- added the rediffed fuzzy patch
- rebuild

* Fri Nov 14 2008 Funda Wang <fwang@mandriva.org> 2.6.2-1mdv2009.1
+ Revision: 302959
- New version 2.6.2

* Tue Nov 11 2008 Funda Wang <fwang@mandriva.org> 2.6.1-1mdv2009.1
+ Revision: 302030
- New version 2.6.1

* Wed Oct 22 2008 Funda Wang <fwang@mandriva.org> 2.6.0-1mdv2009.1
+ Revision: 296359
- New version 2.6.0

* Sat Oct 11 2008 Funda Wang <fwang@mandriva.org> 2.4.2-1mdv2009.1
+ Revision: 291789
- New version 2.4.2
- patch0 merged upstream

* Sun Jul 13 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 2.4.1-1mdv2009.0
+ Revision: 234268
- update to new version 2.4.1
- fix typo in patch name

* Mon Jun 23 2008 Oden Eriksson <oeriksson@mandriva.com> 2.4.0-2mdv2009.0
+ Revision: 227987
- rebuilt due to PayloadIsLzma problems

* Sat Jun 21 2008 Funda Wang <fwang@mandriva.org> 2.4.0-1mdv2009.0
+ Revision: 227692
- New version 2.4.0

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

* Thu May 29 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 2.3.11-1mdv2009.0
+ Revision: 212897
- update to new version 2.3.11
- enable support for libzo
- compile with system-wide libtasn1
- enable checks
- do not package COPYING file
- Patch0: add missing header

* Sat May 17 2008 Funda Wang <fwang@mandriva.org> 2.3.9-1mdv2009.0
+ Revision: 208538
- New version 2.3.9

* Wed May 07 2008 Funda Wang <fwang@mandriva.org> 2.3.8-1mdv2009.0
+ Revision: 202890
- New version 2.3.8

  + Guillaume Rousse <guillomovitch@mandriva.org>
    - fix license tag (thanx Adam)

* Wed Feb 20 2008 Guillaume Rousse <guillomovitch@mandriva.org> 2.3.0-2mdv2008.1
+ Revision: 173245
- enable srp authentication, needed by mod_gnutls

* Mon Feb 18 2008 Guillaume Rousse <guillomovitch@mandriva.org> 2.3.0-1mdv2008.1
+ Revision: 171614
- new version
  drop signature file from sources (missing from mirrors)
  disable guile bindings explicitely

* Sat Jan 19 2008 Funda Wang <fwang@mandriva.org> 2.2.1-1mdv2008.1
+ Revision: 155052
- New version 2.2.1

* Sat Jan 12 2008 Funda Wang <fwang@mandriva.org> 2.2.0-1mdv2008.1
+ Revision: 149636
- BR opencdk 0.6.x
- WARNING: New major 13->26

  + Tomasz Pawel Gajc <tpg@mandriva.org>
    - new version

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Sat Nov 17 2007 Funda Wang <fwang@mandriva.org> 2.0.4-1mdv2008.1
+ Revision: 109266
- New version 2.0.4

* Sun Oct 28 2007 Funda Wang <fwang@mandriva.org> 2.0.2-1mdv2008.1
+ Revision: 102896
- New versino 2.0.2

* Tue Sep 18 2007 Funda Wang <fwang@mandriva.org> 2.0.0-2mdv2008.0
+ Revision: 89561
- Force rebuild

* Wed Sep 05 2007 Funda Wang <fwang@mandriva.org> 2.0.0-1mdv2008.0
+ Revision: 79694
- Correct license of library
- New version 2.0.0

* Thu Jul 12 2007 Tomasz Pawel Gajc <tpg@mandriva.org> 1.6.3-1mdv2008.0
+ Revision: 51577
- disable rpath
- compile with gcrypt support
- new version
- new devel library policy


* Tue Jan 23 2007 Stew Benedict <sbenedict@mandriva.com> 1.6.1-1mdv2007.0
+ Revision: 112605
- 1.6.1
  drop P0 - merged upstream
  work around %%multiarch weirdness for multiple files

* Thu Nov 16 2006 Stew Benedict <sbenedict@mandriva.com> 1.4.5-1mdv2007.1
+ Revision: 85045
- Import gnutls

* Thu Nov 16 2006 Stew Benedict <sbenedict@mandriva.com> 1.4.5-1mdv2007.1
- 1.4.5

* Thu Sep 21 2006 Nicolas Lécureuil <neoclust@mandriva.org> 1.4.0-4mdv2007.0
- - Rebuild against ncurse

* Wed Sep 20 2006 Stew Benedict <sbenedict@mandriva.com> 1.4.0-3mdv2007.0
- P0: security fix for CVE-2006-4790

* Tue Sep 19 2006 Gwenole Beauchesne <gbeauchesne@mandriva.com> 1.4.0-2mdv2007.0
- Rebuild

* Fri May 26 2006 Stew Benedict <sbenedict@mandriva.com> 1.4.0-1mdv2007.0
- 1.4.0

* Sat Apr 15 2006 Stew Benedict <sbenedict@mandriva.com> 1.0.25-4mdk
- P3: security fix for CVE-2006-0645

* Sat Dec 31 2005 Mandriva Linux Team <http://www.mandrivaexpert.com/> 1.0.25-3mdk
- Rebuild

* Wed Jun 29 2005 Götz Waschk <waschk@mandriva.org> 1.0.25-2mdk
- replace source 2 by patch 2 and update it for new liblzo

* Thu Jun 02 2005 Götz Waschk <waschk@mandriva.org> 1.0.25-1mdk
- update patch 1
- update minilzo to 2.00
- new version

* Thu Feb 03 2005 Abel Cheung <deaddog@mandrake.org> 1.0.23-2mdk
- multiarch

* Wed Dec 22 2004 Per Øyvind Karlsen <peroyvind@linux-mandrake.com> 1.0.23-1mdk
- 1.0.23
- fix %%libname_orig
- remove patent tainted SRP code (P1 from fedora)
- drop P0 (fixed upstream)
- fix summary-ended-with-dot

* Fri May 21 2004 Abel Cheung <deaddog@deaddog.org> 1.0.13-1mdk
- New version
- Patch0: automake 1.8 compatibility

* Tue Apr 06 2004 Thierry Vignaud <tvignaud@mandrakesoft.com> 1.0.10-1mdk
- new release

